@@ -69,7 +69,7 @@ impl TickFormat for IntegerTickFmt {
 
 impl HasDefaultTicks for i128 {
     type Fmt = IntegerTickFmt;
-    fn generate(bound: crate::Bound<i128>) -> (TickInfo<i128>, IntegerTickFmt) {
+    fn generate(bound: &crate::Bound<i128>) -> (TickInfo<i128>, IntegerTickFmt) {
         let range = [bound.min, bound.max];
         let ideal_num_steps = bound.ideal_num_steps;
         let dash = bound.dash_info;
@@ -87,11 +87,7 @@ impl HasDefaultTicks for i128 {
         let axis = bound.axis;
 
         (
-            TickInfo {
-                bound,
-                ticks,
-                dash_size,
-            },
+            TickInfo { ticks, dash_size },
             IntegerTickFmt {
                 step: tick_layout.step,
                 offset,
