@@ -76,6 +76,22 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
 
     let first_ticky = ytick_info.ticks[0];
 
+    let (distance_to_firstx, distancex_min_to_max) = {
+        let d1 = minx.scale([minx, maxx], scalex);
+        let d2 = first_tickx.scale([minx, maxx], scalex);
+        let distance_to_firstx = d2 - d1;
+        let distancex_min_to_max = maxx.scale([minx, maxx], scalex) - d1;
+        (distance_to_firstx, distancex_min_to_max)
+    };
+
+    let (distance_to_firsty, distancey_min_to_max) = {
+        let d1 = miny.scale([miny, maxy], scaley);
+        let d2 = first_ticky.scale([miny, maxy], scaley);
+        let distance_to_firsty = d2 - d1;
+        let distancey_min_to_max = maxy.scale([miny, maxy], scaley) - d1;
+        (distance_to_firsty, distancey_min_to_max)
+    };
+
     {
         //step num is assured to be atleast 1.
         writer
@@ -101,6 +117,20 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
                 d.attr("y2", yaspect_offset + height - paddingy * 0.95)
             })?;
 
+            if plotter.plots.xtick_lines {
+                writer.single("line", |d| {
+                    d.attr("class", "poloto_tick_line")?;
+                    d.attr("stroke", "black")?;
+                    d.attr("x1", xaspect_offset + xx)?;
+                    d.attr("x2", xaspect_offset + xx)?;
+                    d.attr("y1", yaspect_offset + height - paddingy)?;
+                    d.attr(
+                        "y2",
+                        yaspect_offset + height - paddingy - distancey_min_to_max,
+                    )
+                })?;
+            }
+
             writer
                 .elem("text", |d| {
                     d.attr("class", "poloto_tick_labels poloto_text")?;
@@ -140,6 +170,17 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
                 d.attr("y2", yaspect_offset + yy)
             })?;
 
+            if plotter.plots.ytick_lines {
+                writer.single("line", |d| {
+                    d.attr("class", "poloto_tick_line")?;
+                    d.attr("stroke", "black")?;
+                    d.attr("x1", xaspect_offset + padding)?;
+                    d.attr("x2", padding + xaspect_offset + distancex_min_to_max)?;
+                    d.attr("y1", yaspect_offset + yy)?;
+                    d.attr("y2", yaspect_offset + yy)
+                })?;
+            }
+
             writer
                 .elem("text", |d| {
                     d.attr("class", "poloto_tick_labels poloto_text")?;
@@ -152,11 +193,6 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
         }
     }
 
-    let d1 = minx.scale([minx, maxx], scalex);
-    let d2 = first_tickx.scale([minx, maxx], scalex);
-    let distance_to_firstx = d2 - d1;
-    let distancex_min_to_max = maxx.scale([minx, maxx], scalex) - d1;
-
     writer.single("path", |d| {
         d.attr("stroke", "black")?;
         d.attr("fill", "none")?;
@@ -183,11 +219,6 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
         })
     })?;
 
-    let d1 = miny.scale([miny, maxy], scaley);
-    let d2 = first_ticky.scale([miny, maxy], scaley);
-    let distance_to_firsty = d2 - d1;
-    let distancey_min_to_max = maxy.scale([miny, maxy], scaley) - d1;
-
     writer.single("path", |d| {
         d.attr("stroke", "black")?;
         d.attr("fill", "none")?;
